@@ -236,10 +236,10 @@ public:
 	bool done;
 	Names n;
 
-	ProtossMacroEnv(const Names& myNames, const vector<AssetStats>& myAssetList) {
+	ProtossMacroEnv() {
 		REGEN_RATE = 1;
-		n = myNames;
-		assetList = myAssetList;
+		n = Names();
+		loadStatCatalog();
 		for (int i = 0; i < assetList.size(); i++) {
 			state.push_back(0);
 		}
@@ -260,9 +260,9 @@ public:
 		time = env.time;
 		REGEN_RATE = env.REGEN_RATE;
 
-		//shallow copy
-		n = env.n;
-		assetList = env.assetList;
+		//reload these from scratch for now
+		n = Names()
+		assetList = loadStatCatalog();
 
 		//deep copy
 		copyEntityList(env.entityList);
@@ -271,6 +271,82 @@ public:
 		}
 	}
 
+	void loadStatCatalog() {
+		assetList = {
+			//placeholder
+			AssetStats(n.dummy, 0, 0, 0, 0, 0, n.dummy, { n.dummy }, 1, false),
+			//units
+			AssetStats(n.probe, 50, 0, 1, 0, 12, n.nexus, { n.nexus }, 20, false),
+			AssetStats(n.zealot, 100,0,2,0,27,n.gateway,{n.gateway}, 10, false),
+			AssetStats(n.sentry,50,100,2,0,26,n.gateway,{n.gateway,n.cyberneticscore},100,false),
+			AssetStats(n.stalker,215,50,2,0,30,n.gateway,{n.gateway,n.cyberneticscore},10,false),
+			AssetStats(n.adept,100,25,2,0,27,n.gateway,{n.gateway,n.cyberneticscore},10,false),
+			AssetStats(n.hightemplar,50,150,2,0,39,n.gateway,{n.gateway,n.templararchives},10,false),
+			AssetStats(n.darktemplar,125,125,2,0,39,n.gateway,{n.gateway,n.darkshrine},10,false),
+			AssetStats(n.observer,25,75,1,0,21,n.roboticsfacility,{n.roboticsfacility},10,false),
+			AssetStats(n.warpprism,200,0,2,0,36,n.roboticsfacility,{n.roboticsfacility},10,false),
+			AssetStats(n.immortal,275,100,4,0,39,n.roboticsfacility,{n.roboticsfacility},10,false),
+			AssetStats(n.colossus,300,200,6,0,54,n.roboticsfacility,{n.roboticsfacility,n.roboticsbay},10,false),
+			AssetStats(n.disruptor,150,150,3,0,36,n.roboticsfacility,{n.roboticsfacility,n.roboticsbay},10,false),
+			AssetStats(n.phoenix,150,100,2,0,25,n.stargate,{n.stargate},10,false),
+			AssetStats(n.oracle,150,150,3,0,37,n.stargate,{n.stargate},10,false),
+			AssetStats(n.voidray,200,100,4,0,37,n.stargate,{n.stargate},10,false),
+			AssetStats(n.tempest,250,175,5,0,43,n.stargate,{n.stargate,n.fleetbeacon},10,false),
+			AssetStats(n.carrier,350,250,6,0,64,n.stargate,{n.stargate,n.fleetbeacon},10,false),
+			AssetStats(n.warpzealot, 100,0,2,0,7,n.warpgate,{n.warpgate}, 10, false),
+			AssetStats(n.warpsentry,50,100,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},100,false),
+			AssetStats(n.warpstalker,215,50,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},10,false),
+			AssetStats(n.warpadept,100,25,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},10,false),
+			AssetStats(n.warphightemplar,50,150,2,0,7,n.warpgate,{n.warpgate,n.templararchives},10,false),
+			AssetStats(n.warpdarktemplar,125,125,2,0,7,n.warpgate,{n.warpgate,n.darkshrine},10,false),
+			//buildings
+			AssetStats(n.nexus, 400, 0, 0,15, 71, NULL,{}, 3, true),
+			AssetStats(n.pylon, 100, 0, 0,8, 18, NULL,{}, 10, false),
+			AssetStats(n.assimilator, 75, 0, 0,0, 21, NULL,{}, 8, false),
+			AssetStats(n.gateway, 150, 0, 0,0, 46, NULL,{n.pylon}, 10, true),
+			AssetStats(n.forge, 150, 0, 0,0, 32, NULL,{n.pylon}, 3, true),
+			AssetStats(n.photoncannon, 150, 0, 0,0, 29, NULL,{n.forge}, 5, false),
+			AssetStats(n.shieldbattery, 100, 0, 0,0, 29, NULL,{n.cyberneticscore}, 5, false),
+			AssetStats(n.warpgate, 0, 0, 0,0, 7, NULL,{n.warpgateresearch,n.gateway}, 10, true),
+			AssetStats(n.cyberneticscore, 150, 0, 0, 0,36, NULL,{n.gateway}, 3, true),
+			AssetStats(n.twilightcouncil, 150, 100, 0,0, 36, NULL,{n.cyberneticscore}, 3, true),
+			AssetStats(n.roboticsfacility, 150, 100, 0, 0,46, NULL,{n.cyberneticscore}, 10, true),
+			AssetStats(n.stargate, 150, 150, 0, 0,43, NULL,{n.cyberneticscore}, 10, true),
+			AssetStats(n.templararchives, 150, 200, 0,0, 36, NULL,{n.twilightcouncil}, 1, true),
+			AssetStats(n.darkshrine, 150, 150, 0,0, 71, NULL,{n.twilightcouncil}, 1, true),
+			AssetStats(n.roboticsbay, 150, 150, 0,0, 46, NULL,{n.roboticsfacility}, 3, true),
+			AssetStats(n.fleetbeacon, 300, 200, 0,0, 43, NULL,{n.stargate}, 3, true),
+			//upgrades
+			AssetStats(n.groundweapons1, 100, 100, 0,0, 129,n.forge,{n.forge}, 1, false),
+			AssetStats(n.groundarmor1, 100, 100, 0,0, 129,n.forge,{n.forge}, 1, false),
+			AssetStats(n.airweapons1, 100, 100, 0,0, 129,n.cyberneticscore,{n.cyberneticscore}, 1, false),
+			AssetStats(n.airarmor1, 150, 150, 0,0, 129,n.cyberneticscore,{n.cyberneticscore}, 1, false),
+			AssetStats(n.shields1, 150, 150, 0,0, 129, n.forge,{n.forge}, 1, false),
+			AssetStats(n.groundweapons2, 150, 150, 0,0, 154,n.forge,{n.twilightcouncil, n.forge, n.groundweapons1}, 1, false),
+			AssetStats(n.groundarmor2, 150, 150, 0,0, 154,n.forge,{n.twilightcouncil, n.forge, n.groundarmor1}, 1, false),
+			AssetStats(n.airweapons2, 175, 175, 0,0, 154,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airweapons1}, 1, false),
+			AssetStats(n.airarmor2, 225, 225, 0,0, 154,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airarmor1}, 1, false),
+			AssetStats(n.shields2, 225, 225, 0,0, 154, n.forge,{n.twilightcouncil, n.forge, n.shields1}, 1, false),
+			AssetStats(n.groundweapons3, 200, 200, 0,0, 179,n.forge,{n.twilightcouncil, n.forge, n.groundweapons2}, 1, false),
+			AssetStats(n.groundarmor3, 200, 200, 0,0, 179,n.forge,{n.twilightcouncil, n.forge, n.groundarmor2}, 1, false),
+			AssetStats(n.airweapons3, 250, 250, 0,0, 179,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airweapons2}, 1, false),
+			AssetStats(n.airarmor3, 300, 300, 0,0, 179,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airarmor1}, 1, false),
+			AssetStats(n.shields3, 300, 300, 0,0, 179, n.forge,{n.twilightcouncil, n.forge, n.shields2}, 1, false),
+			AssetStats(n.charge, 100, 100, 0,0, 100, n.twilightcouncil,{n.twilightcouncil}, 1, false),
+			AssetStats(n.graviticdrive, 100, 100, 0,0, 57,n.roboticsbay,{n.roboticsbay}, 1, false),
+			AssetStats(n.resonatingglaives, 100, 100, 0,0, 100,n.twilightcouncil,{n.twilightcouncil}, 1, false),
+			AssetStats(n.graviticboosters, 100, 100, 0,0, 57,n.roboticsbay,{n.roboticsbay}, 1, false),
+			AssetStats(n.fluxvanes, 100, 100, 0,0, 57, n.fleetbeacon,{n.fleetbeacon}, 1, false),
+			AssetStats(n.anionpulsecrystals, 150, 150, 0,0, 64,n.fleetbeacon,{n.fleetbeacon}, 1, false),
+			AssetStats(n.extendedthermallance, 150, 150, 0,0, 100,n.roboticsbay,{n.roboticsbay}, 1, false),
+			AssetStats(n.psionicstorm, 200, 200, 0,0, 79,n.templararchives,{n.templararchives}, 1, false),
+			AssetStats(n.blink, 150, 150, 0, 0,121, n.twilightcouncil,{n.twilightcouncil}, 1, false),
+			AssetStats(n.shadowstride, 100, 100, 0,0, 100,n.darkshrine,{n.darkshrine}, 1, false),
+			AssetStats(n.warpgateresearch, 50, 50, 0, 0,100,n.cyberneticscore,{n.cyberneticscore}, 1, false),
+			AssetStats(n.gravitoncatapult, 150, 150, 0,0, 57,n.fleetbeacon,{n.fleetbeacon}, 1, false),
+		};
+	}
+
 	void initGoalState() {
 		for (size_t i = 0; i < assetList.size(); i++) {
 			goalState.push_back(0);
@@ -608,8 +684,7 @@ public:
 	Names n;
 
 	GeneralLoader() {
-		n = Names();
-		loadStatCatalog();
+		
 	}
 
 	//create an environment from here that will have references to this object
@@ -623,81 +698,7 @@ public:
 		return env;
 	}
 
-	void loadStatCatalog() {
-		assetList = {
-			//placeholder
-			AssetStats(n.dummy, 0, 0, 0, 0, 0, n.dummy, { n.dummy }, 1, false),
-			//units
-			AssetStats(n.probe, 50, 0, 1, 0, 12, n.nexus, { n.nexus }, 20, false),
-			AssetStats(n.zealot, 100,0,2,0,27,n.gateway,{n.gateway}, 10, false),
-			AssetStats(n.sentry,50,100,2,0,26,n.gateway,{n.gateway,n.cyberneticscore},100,false),
-			AssetStats(n.stalker,215,50,2,0,30,n.gateway,{n.gateway,n.cyberneticscore},10,false),
-			AssetStats(n.adept,100,25,2,0,27,n.gateway,{n.gateway,n.cyberneticscore},10,false),
-			AssetStats(n.hightemplar,50,150,2,0,39,n.gateway,{n.gateway,n.templararchives},10,false),
-			AssetStats(n.darktemplar,125,125,2,0,39,n.gateway,{n.gateway,n.darkshrine},10,false),
-			AssetStats(n.observer,25,75,1,0,21,n.roboticsfacility,{n.roboticsfacility},10,false),
-			AssetStats(n.warpprism,200,0,2,0,36,n.roboticsfacility,{n.roboticsfacility},10,false),
-			AssetStats(n.immortal,275,100,4,0,39,n.roboticsfacility,{n.roboticsfacility},10,false),
-			AssetStats(n.colossus,300,200,6,0,54,n.roboticsfacility,{n.roboticsfacility,n.roboticsbay},10,false),
-			AssetStats(n.disruptor,150,150,3,0,36,n.roboticsfacility,{n.roboticsfacility,n.roboticsbay},10,false),
-			AssetStats(n.phoenix,150,100,2,0,25,n.stargate,{n.stargate},10,false),
-			AssetStats(n.oracle,150,150,3,0,37,n.stargate,{n.stargate},10,false),
-			AssetStats(n.voidray,200,100,4,0,37,n.stargate,{n.stargate},10,false),
-			AssetStats(n.tempest,250,175,5,0,43,n.stargate,{n.stargate,n.fleetbeacon},10,false),
-			AssetStats(n.carrier,350,250,6,0,64,n.stargate,{n.stargate,n.fleetbeacon},10,false),
-			AssetStats(n.warpzealot, 100,0,2,0,7,n.warpgate,{n.warpgate}, 10, false),
-			AssetStats(n.warpsentry,50,100,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},100,false),
-			AssetStats(n.warpstalker,215,50,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},10,false),
-			AssetStats(n.warpadept,100,25,2,0,7,n.warpgate,{n.warpgate,n.cyberneticscore},10,false),
-			AssetStats(n.warphightemplar,50,150,2,0,7,n.warpgate,{n.warpgate,n.templararchives},10,false),
-			AssetStats(n.warpdarktemplar,125,125,2,0,7,n.warpgate,{n.warpgate,n.darkshrine},10,false),
-			//buildings
-			AssetStats(n.nexus, 400, 0, 0,15, 71, NULL,{}, 3, true),
-			AssetStats(n.pylon, 100, 0, 0,8, 18, NULL,{}, 10, false),
-			AssetStats(n.assimilator, 75, 0, 0,0, 21, NULL,{}, 8, false),
-			AssetStats(n.gateway, 150, 0, 0,0, 46, NULL,{n.pylon}, 10, true),
-			AssetStats(n.forge, 150, 0, 0,0, 32, NULL,{n.pylon}, 3, true),
-			AssetStats(n.photoncannon, 150, 0, 0,0, 29, NULL,{n.forge}, 5, false),
-			AssetStats(n.shieldbattery, 100, 0, 0,0, 29, NULL,{n.cyberneticscore}, 5, false),
-			AssetStats(n.warpgate, 0, 0, 0,0, 7, NULL,{n.warpgateresearch,n.gateway}, 10, true),
-			AssetStats(n.cyberneticscore, 150, 0, 0, 0,36, NULL,{n.gateway}, 3, true),
-			AssetStats(n.twilightcouncil, 150, 100, 0,0, 36, NULL,{n.cyberneticscore}, 3, true),
-			AssetStats(n.roboticsfacility, 150, 100, 0, 0,46, NULL,{n.cyberneticscore}, 10, true),
-			AssetStats(n.stargate, 150, 150, 0, 0,43, NULL,{n.cyberneticscore}, 10, true),
-			AssetStats(n.templararchives, 150, 200, 0,0, 36, NULL,{n.twilightcouncil}, 1, true),
-			AssetStats(n.darkshrine, 150, 150, 0,0, 71, NULL,{n.twilightcouncil}, 1, true),
-			AssetStats(n.roboticsbay, 150, 150, 0,0, 46, NULL,{n.roboticsfacility}, 3, true),
-			AssetStats(n.fleetbeacon, 300, 200, 0,0, 43, NULL,{n.stargate}, 3, true),
-			//upgrades
-			AssetStats(n.groundweapons1, 100, 100, 0,0, 129,n.forge,{n.forge}, 1, false),
-			AssetStats(n.groundarmor1, 100, 100, 0,0, 129,n.forge,{n.forge}, 1, false),
-			AssetStats(n.airweapons1, 100, 100, 0,0, 129,n.cyberneticscore,{n.cyberneticscore}, 1, false),
-			AssetStats(n.airarmor1, 150, 150, 0,0, 129,n.cyberneticscore,{n.cyberneticscore}, 1, false),
-			AssetStats(n.shields1, 150, 150, 0,0, 129, n.forge,{n.forge}, 1, false),
-			AssetStats(n.groundweapons2, 150, 150, 0,0, 154,n.forge,{n.twilightcouncil, n.forge, n.groundweapons1}, 1, false),
-			AssetStats(n.groundarmor2, 150, 150, 0,0, 154,n.forge,{n.twilightcouncil, n.forge, n.groundarmor1}, 1, false),
-			AssetStats(n.airweapons2, 175, 175, 0,0, 154,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airweapons1}, 1, false),
-			AssetStats(n.airarmor2, 225, 225, 0,0, 154,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airarmor1}, 1, false),
-			AssetStats(n.shields2, 225, 225, 0,0, 154, n.forge,{n.twilightcouncil, n.forge, n.shields1}, 1, false),
-			AssetStats(n.groundweapons3, 200, 200, 0,0, 179,n.forge,{n.twilightcouncil, n.forge, n.groundweapons2}, 1, false),
-			AssetStats(n.groundarmor3, 200, 200, 0,0, 179,n.forge,{n.twilightcouncil, n.forge, n.groundarmor2}, 1, false),
-			AssetStats(n.airweapons3, 250, 250, 0,0, 179,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airweapons2}, 1, false),
-			AssetStats(n.airarmor3, 300, 300, 0,0, 179,n.cyberneticscore,{n.cyberneticscore, n.fleetbeacon, n.airarmor1}, 1, false),
-			AssetStats(n.shields3, 300, 300, 0,0, 179, n.forge,{n.twilightcouncil, n.forge, n.shields2}, 1, false),
-			AssetStats(n.charge, 100, 100, 0,0, 100, n.twilightcouncil,{n.twilightcouncil}, 1, false),
-			AssetStats(n.graviticdrive, 100, 100, 0,0, 57,n.roboticsbay,{n.roboticsbay}, 1, false),
-			AssetStats(n.resonatingglaives, 100, 100, 0,0, 100,n.twilightcouncil,{n.twilightcouncil}, 1, false),
-			AssetStats(n.graviticboosters, 100, 100, 0,0, 57,n.roboticsbay,{n.roboticsbay}, 1, false),
-			AssetStats(n.fluxvanes, 100, 100, 0,0, 57, n.fleetbeacon,{n.fleetbeacon}, 1, false),
-			AssetStats(n.anionpulsecrystals, 150, 150, 0,0, 64,n.fleetbeacon,{n.fleetbeacon}, 1, false),
-			AssetStats(n.extendedthermallance, 150, 150, 0,0, 100,n.roboticsbay,{n.roboticsbay}, 1, false),
-			AssetStats(n.psionicstorm, 200, 200, 0,0, 79,n.templararchives,{n.templararchives}, 1, false),
-			AssetStats(n.blink, 150, 150, 0, 0,121, n.twilightcouncil,{n.twilightcouncil}, 1, false),
-			AssetStats(n.shadowstride, 100, 100, 0,0, 100,n.darkshrine,{n.darkshrine}, 1, false),
-			AssetStats(n.warpgateresearch, 50, 50, 0, 0,100,n.cyberneticscore,{n.cyberneticscore}, 1, false),
-			AssetStats(n.gravitoncatapult, 150, 150, 0,0, 57,n.fleetbeacon,{n.fleetbeacon}, 1, false),
-		};
-	}
+	
 };
 
 
@@ -715,13 +716,9 @@ PYBIND11_MODULE(probotest1, m) {
 
     )pbdoc";
 
-	pybind11::class_<GeneralLoader>(m, "GeneralLoader")
-		.def(pybind11::init<>())
-		.def("createFreshEnv", &GeneralLoader::createFreshEnv)
-		.def("deepCopyEnv", &GeneralLoader::deepCopyEnv)
-		;
-
     pybind11::class_<ProtossMacroEnv>(m, "ProtossMacroEnv")
+		.def(pybind11::init<>())
+		.def(pybind11::init<const ProtossMacroEnv&>())
         .def("step", &ProtossMacroEnv::step)
 		.def("reset", &ProtossMacroEnv::reset)
 		.def("getEntityList", &ProtossMacroEnv::getState)
